@@ -8,10 +8,14 @@ import pandas as pd
 import synapseclient
 from synapseclient.core.retry import with_retry
 from synapseclient.core.utils import from_unix_epoch_time
+from synapseclient.core.exceptions import (
+    SynapseNoCredentialsError,
+    SynapseAuthenticationError,
+)
 
 from . import (annotations, createchallenge, challenge,
-               evaluation_queue, helpers, mirrorwiki, permissions,
-               submission, utils, wiki)
+               evaluation_queue, mirrorwiki, permissions,
+               submission, utils, wiki,)
 from .__version__ import __version__
 
 logging.basicConfig(level=logging.INFO)
@@ -266,16 +270,16 @@ def command_send_email(syn, args):
                     messageBody=message)
 
 
-def command_kill_docker_over_quota(syn, args):
+def command_stop_submission_over_quota(syn, args):
     """
     Sets an annotation on Synapse Docker submissions such that it will
     be terminated by the orchestrator. Usually applies to submissions
     that have been running for longer than the alloted time.
 
-    >>> challengeutils killdockeroverquota evaluationid quota
+    >>> challengeutils stop-submission-over-quota submission_viewid quota
     """
-    helpers.kill_docker_submission_over_quota(syn, args.evaluationid,
-                                              quota=args.quota)
+    submission.stop_submission_over_quota(syn, args.submission_viewid,
+                                          quota=args.quota)
 
 
 def command_validate_docker(syn, args):
@@ -608,20 +612,22 @@ def build_parser():
 
     parser_send_email.set_defaults(func=command_send_email)
 
-    parser_kill_docker = subparsers.add_parser(
-        'kill-docker-over-quota',
-        help='Kill Docker submissions over the quota')
+    parser_stop_submission = subparsers.add_parser(
+        'stop-submission-over-quota',
+        help='Stop Docker submissions over the quota')
 
-    parser_kill_docker.add_argument(
-        "evaluationid",
+    parser_stop_submission.add_argument(
+        "submission_viewid",
         type=str,
-        help='Synapse evaluation queue id')
+        help='Synapse Submission View Id')
 
-    parser_kill_docker.add_argument(
+    parser_stop_submission.add_argument(
         "quota",
         type=int,
         help="Time quota submission has to run in milliseconds")
-    parser_kill_docker.set_defaults(func=command_kill_docker_over_quota)
+    parser_stop_submission.set_defaults(
+        func=command_stop_submission_over_quota
+    )
 
     parser_set_quota = subparsers.add_parser(
         'set-evaluation-quota',
@@ -789,19 +795,40 @@ def build_parser():
     return parser
 
 
-def synapse_login(synapse_config):
+def synapse_login(synapse_config=synapseclient.client.CONFIG_FILE):
+    """Login to Synapse
+
+    Args:
+        synapse_config: Path to synapse configuration file.
+                        Defaults to ~/.synapseConfig
+
+    Returns:
+        Synapse connection
+    """
     try:
-        syn = synapseclient.login(silent=True)
-    except Exception:
         syn = synapseclient.Synapse(configPath=synapse_config)
         syn.login(silent=True)
-    return(syn)
+    except (SynapseNoCredentialsError, SynapseAuthenticationError):
+        raise ValueError(
+            "Login error: please make sure you have correctly "
+            "configured your client.  Instructions here: "
+            "https://help.synapse.org/docs/Client-Configuration.1985446156.html. "
+            "You can also create a Synapse Personal Access Token and set it "
+            "as an environmental variable: "
+            "SYNAPSE_AUTH_TOKEN='<my_personal_access_token>'"
+        )
+    return syn
 
 
 def main():
-    args = build_parser().parse_args()
+    parser = build_parser()
+    args = parser.parse_args()
     syn = synapse_login(args.synapse_config)
-    args.func(syn, args)
+    try:
+        args.func(syn, args)
+    except AttributeError:
+        parser.print_help()
+        parser.exit()
 
 
 if __name__ == "__main__":
